@@ -1,13 +1,16 @@
 ##############################################################################
 #      $URL: http://perlcritic.tigris.org/svn/perlcritic/trunk/Perl-Critic-More/lib/Perl/Critic/More.pm $
-#     $Date: 2006-11-15 15:58:24 -0600 (Wed, 15 Nov 2006) $
+#     $Date: 2006-11-23 22:58:14 -0600 (Thu, 23 Nov 2006) $
 #   $Author: chrisdolan $
-# $Revision: 871 $
+# $Revision: 917 $
 ##############################################################################
 package Perl::Critic::More;
+
+use v5.6;
 use warnings;
 use strict;
-our $VERSION = 0.11;
+our $VERSION = 0.12;
+
 1;
 
 __END__
@@ -86,4 +89,4 @@ can be found in the LICENSE file included with this module.
 #   indent-tabs-mode: nil
 #   c-indentation-style: bsd
 # End:
-# ex: set ts=8 sts=4 sw=4 expandtab
+# ex: set ts=8 sts=4 sw=4 expandtab :
