@@ -1,51 +1,44 @@
 #######################################################################
-#      $URL: http://perlcritic.tigris.org/svn/perlcritic/trunk/Perl-Critic-More/lib/Perl/Critic/Policy/CodeLayout/RequireASCII.pm $
-#     $Date: 2008-05-18 19:30:24 -0500 (Sun, 18 May 2008) $
-#   $Author: clonezone $
-# $Revision: 2372 $
+#      $URL$
+#     $Date$
+#   $Author$
+# $Revision$
 ########################################################################
 
 package Perl::Critic::Policy::CodeLayout::RequireASCII;
 
-use 5.006;
+use v5.6;
 use strict;
 use warnings;
-
-use Readonly;
-
+use Perl::Critic::Utils;
 use List::MoreUtils qw(none any);
-
-use Perl::Critic::Utils qw{ :severities };
 use base 'Perl::Critic::Policy';
 
-our $VERSION = '0.999_002';
-
-Readonly::Scalar my $MAX_ASCII_VALUE => 127;
+our $VERSION = 0.12;
 
 #---------------------------------------------------------------------------
 
-Readonly::Scalar my $DESC => 'Use only ASCII code';
-Readonly::Scalar my $EXPL => 'Put any non-ASCII in separate files';
+my $desc = 'Use only ASCII code';
+my $expl = 'Put any non-ASCII in separate files';
 
 #---------------------------------------------------------------------------
 
-sub default_severity     { return $SEVERITY_LOWEST }
-sub default_themes       { return qw< more notrecommended > }
-sub applies_to           { return 'PPI::Token' }
-sub supported_parameters { return () }
+sub default_severity { return $SEVERITY_LOWEST }
+sub default_themes   { return qw(more notrecommended) }
+sub applies_to       { return 'PPI::Token' }
 
 #---------------------------------------------------------------------------
 
 sub violates {
     my ( $self, $elem, $doc ) = @_;
 
-    if ( any { $_ > $MAX_ASCII_VALUE } unpack 'C*', "$elem" ) {
-        return $self->violation( $DESC, $EXPL, $elem );
+    if ( any { $_ > 127 } unpack 'C*', "$elem" ) {
+        return $self->violation( $desc, $expl, $elem );
     }
     if ( $elem->isa('PPI::Token::HereDoc') ) {
         for my $line ( $elem->heredoc ) {
-            if ( any { $_ > $MAX_ASCII_VALUE } unpack 'C*', $line ) {
-                return $self->violation( $DESC, $EXPL, $elem );
+            if ( any { $_ > 127 } unpack 'C*', $line ) {
+                return $self->violation( $desc, $expl, $elem );
             }
         }
     }
@@ -65,12 +58,7 @@ __END__
 
 =head1 NAME
 
-Perl::Critic::Policy::CodeLayout::RequireASCII - Disallow high-bit characters.
-
-=head1 AFFILIATION
-
-This policy is part of L<Perl::Critic::More>, a bleeding edge supplement to
-L<Perl::Critic>.
+Perl::Critic::Policy::CodeLayout::RequireASCII - Disallow high-bit characters
 
 =head1 DESCRIPTION
 
@@ -98,7 +86,7 @@ Chris Dolan <cdolan@cpan.org>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2006-2008 Chris Dolan
+Copyright (c) 2006 Chris Dolan
 
 This program is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.  The full text of this license
@@ -113,4 +101,4 @@ can be found in the LICENSE file included with this module.
 #   indent-tabs-mode: nil
 #   c-indentation-style: bsd
 # End:
-# ex: set ts=8 sts=4 sw=4 tw=78 ft=perl expandtab shiftround :
+# ex: set ts=8 sts=4 sw=4 expandtab :
