@@ -1,70 +1,49 @@
 #######################################################################
 #      $URL: http://perlcritic.tigris.org/svn/perlcritic/trunk/Perl-Critic-More/lib/Perl/Critic/Policy/Modules/PerlMinimumVersion.pm $
-#     $Date: 2008-05-18 19:33:53 -0500 (Sun, 18 May 2008) $
-#   $Author: clonezone $
-# $Revision: 2373 $
+#     $Date: 2006-11-23 22:58:14 -0600 (Thu, 23 Nov 2006) $
+#   $Author: chrisdolan $
+# $Revision: 917 $
 ########################################################################
 
 package Perl::Critic::Policy::Modules::PerlMinimumVersion;
 
-use 5.006;
+use v5.6;
 use strict;
 use warnings;
-
+use Perl::Critic::Utils;
 use English qw(-no_match_vars);
-use Readonly;
-
-use Perl::Critic::Utils qw{ :severities };
-
+use Carp;
 use base 'Perl::Critic::Policy';
 
-our $VERSION = '0.999_002';
+our $VERSION = 0.12;
 
 #---------------------------------------------------------------------------
 
-Readonly::Scalar my $DESC =>
-    'Avoid Perl features newer than specified version';
-Readonly::Scalar my $EXPL => 'Improve your backward compatibility';
+my $desc = 'Avoid Perl features newer than specified version';
+my $expl = 'Improve your backward compatibility';
 
 #---------------------------------------------------------------------------
 
 sub default_severity { return $SEVERITY_LOWEST }
-sub default_themes   { return qw< more compatibility > }
+sub default_themes   { return qw(more compatibility) }
 sub applies_to       { return 'PPI::Document' }
 
-sub supported_parameters {
-    return (
-        {   name        => 'version',
-            description => 'Version of perl to be compatible with.',
-            behavior    => 'string',
-            parser      => \&_parse_version,
-        },
-    );
-}
-
 #---------------------------------------------------------------------------
 
-sub _parse_version {
-    my ( $self, $parameter, $config_string ) = @_;
+sub new {
+    my ( $class, %config ) = @_;
+    my $self = bless {}, $class;
 
-    my $version;
-    if ($config_string) {
-        if ( $config_string =~ m<\A \s* (5 [.] [\d.]+) \s* \z>xms ) {
-            $version = $1;
+    $self->{_version} = $PERL_VERSION;
+    if ( $config{version} ) {
+        if ( $config{version} =~ m/\A \s* (5\.[\d\.]+) \s* \z/xms ) {
+            $self->{_version} = $1;
         } else {
-            $self->throw_parameter_value_exception( 'version', $config_string,
-                undef, "doesn't look like a perl version number.\n",
-            );
+            croak 'Invalid PerlMinimumVersion number in Perl::Critic config';
         }
-    } elsif ( ref $PERL_VERSION ) {
-        $version = $PERL_VERSION->numify();    # It's an object as of 5.10.
-    } else {
-        $version = 0 + $PERL_VERSION;    # numify to get away from version.pm
     }
 
-    $self->{_version} = $version;
-
-    return;
+    return $self;
 }
 
 #---------------------------------------------------------------------------
@@ -78,8 +57,6 @@ sub violates {
     my $checker = Perl::MinimumVersion->new($doc);
 
     # Workaround for Perl::Critic::Document instance in older P::C versions
-    # (pre-v0.22) that didn't have a custom isa() to masquerade as a
-    # PPI::Document
     if ( !$checker ) {
         $checker = Perl::MinimumVersion->new( $doc->{_doc} );
     }
@@ -87,11 +64,9 @@ sub violates {
 
     # this returns a version.pm instance
     my $doc_version = $checker->minimum_version();
-
-    #print "v$doc_version vs. $self->{_version}\n";
     return if $doc_version <= $self->{_version};
 
-    return $self->violation( $DESC, $EXPL, $doc );
+    return $self->violation( $desc, $expl, $doc );
 }
 
 1;
@@ -106,12 +81,7 @@ __END__
 
 =head1 NAME
 
-Perl::Critic::Policy::Modules::PerlMinimumVersion - Enforce backward compatible code.
-
-=head1 AFFILIATION
-
-This policy is part of L<Perl::Critic::More>, a bleeding edge supplement to
-L<Perl::Critic>.
+Perl::Critic::Policy::Modules::PerlMinimumVersion - Enforce backward compatible code
 
 =head1 DESCRIPTION
 
@@ -137,7 +107,7 @@ Chris Dolan <cdolan@cpan.org>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2006-2008 Chris Dolan
+Copyright (c) 2006 Chris Dolan
 
 This program is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.  The full text of this license
@@ -152,4 +122,4 @@ can be found in the LICENSE file included with this module.
 #   indent-tabs-mode: nil
 #   c-indentation-style: bsd
 # End:
-# ex: set ts=8 sts=4 sw=4 tw=78 ft=perl expandtab shiftround :
+# ex: set ts=8 sts=4 sw=4 expandtab :
