@@ -1,34 +1,30 @@
 #######################################################################
 #      $URL: http://perlcritic.tigris.org/svn/perlcritic/trunk/Perl-Critic-More/lib/Perl/Critic/Policy/Modules/RequirePerlVersion.pm $
-#     $Date: 2008-05-18 19:30:24 -0500 (Sun, 18 May 2008) $
-#   $Author: clonezone $
-# $Revision: 2372 $
+#     $Date: 2006-11-23 22:58:14 -0600 (Thu, 23 Nov 2006) $
+#   $Author: chrisdolan $
+# $Revision: 917 $
 ########################################################################
 
 package Perl::Critic::Policy::Modules::RequirePerlVersion;
 
-use 5.006;
+use v5.6;
 use strict;
 use warnings;
-
-use Readonly;
-
-use Perl::Critic::Utils qw{ :severities };
+use Perl::Critic::Utils;
 use base 'Perl::Critic::Policy';
 
-our $VERSION = '0.999_002';
+our $VERSION = 0.12;
 
 #---------------------------------------------------------------------------
 
-Readonly::Scalar my $DESC => 'Missing Perl version';
-Readonly::Scalar my $EXPL => 'Add "use 5.006" or similar';
+my $desc = 'Missing Perl version';
+my $expl = 'Add "use v5.6.0" or similar';
 
 #---------------------------------------------------------------------------
 
-sub default_severity     { return $SEVERITY_LOWEST }
-sub default_themes       { return qw< more compatibility > }
-sub applies_to           { return 'PPI::Document' }
-sub supported_parameters { return () }
+sub default_severity { return $SEVERITY_LOWEST }
+sub default_themes   { return qw(more compatibility) }
+sub applies_to       { return 'PPI::Document' }
 
 #---------------------------------------------------------------------------
 
@@ -40,22 +36,11 @@ sub violates {
         for my $stmt ( @{$includes} ) {
             next if $stmt->type ne 'use';
             return if $stmt->version;
-            return if $stmt->module =~ m<
-                \A
-                v
-                \d+
-                (?:
-                    [.] \d+
-                    (?:
-                        _ \d+
-                    )?
-                )*
-                \z
-            >xms;
+            return if $stmt->module =~ m/\A v\d+(?:\.\d+(?:_\d+)?)*\z/xms;
         }
     }
 
-    return $self->violation( $DESC, $EXPL, $doc );
+    return $self->violation( $desc, $expl, $doc );
 }
 
 1;
@@ -70,12 +55,7 @@ __END__
 
 =head1 NAME
 
-Perl::Critic::Policy::Modules::RequirePerlVersion - Require a C<use 5.006;> or similar.
-
-=head1 AFFILIATION
-
-This policy is part of L<Perl::Critic::More>, a bleeding edge supplement to
-L<Perl::Critic>.
+Perl::Critic::Policy::Modules::RequirePerlVersion - Expect a C<use 5.6.0;> or similar
 
 =head1 DESCRIPTION
 
@@ -94,11 +74,7 @@ or
 
   use v5.6.0;
 
-The former is preferred as the latter can trigger v-string compatibility
-warnings.  (If someone could please explain that to me, I'd really appreciate
-it!)
-
-Additionally, it's good form to state that minimum version in your
+Additionally, it's good form to start that minimum version in your
 F<Makefile.PL> or F<Build.PL> file.
 
 =head1 AUTHOR
@@ -107,7 +83,7 @@ Chris Dolan <cdolan@cpan.org>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2006-2008 Chris Dolan
+Copyright (c) 2006 Chris Dolan
 
 This program is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.  The full text of this license
@@ -122,4 +98,4 @@ can be found in the LICENSE file included with this module.
 #   indent-tabs-mode: nil
 #   c-indentation-style: bsd
 # End:
-# ex: set ts=8 sts=4 sw=4 tw=78 ft=perl expandtab shiftround :
+# ex: set ts=8 sts=4 sw=4 expandtab :
